@@ -4,7 +4,7 @@
 # optiondefaults.py, provides defaults for program options
 #
 # ConvertAll, a units conversion program
-# Copyright (C) 2015, Douglas W. Bell
+# Copyright (C) 2016, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License, either Version 2 or any later
@@ -30,6 +30,7 @@ defaultList = [
     "DecimalPlaces       8",
     "Notation            general",
     "ShowOpButtons       yes",
+    "ShowUnitButtons     yes",
     "RecentUnits         8",
     "LoadLastUnit        no",
     "ShowStartupTip      yes",
@@ -38,10 +39,6 @@ defaultList = [
     "MainDlgYSize        0",
     "MainDlgXPos         0",
     "MainDlgYPos         0",
-    "FinderXSize         0",
-    "FinderYSize         0",
-    "FinderXPos          0",
-    "FinderYPos          0",
     "#",
     "RecentUnit1          ",
     "RecentUnit2          ",
