@@ -4,7 +4,7 @@
 # unitgroup.py, provides a group of units and does conversions
 #
 # ConvertAll, a units conversion program
-# Copyright (C) 2015, Douglas W. Bell
+# Copyright (C) 2017, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License, either Version 2 or any later
@@ -14,11 +14,11 @@
 
 import re
 from math import *
-from unitatom import UnitAtom
+import unitatom
 import unitdata
 
 
-class UnitGroup(object):
+class UnitGroup:
     """Stores, updates and converts a group of units.
     """
     maxDecPlcs = 12
@@ -97,66 +97,30 @@ class UnitGroup(object):
         except IndexError:
             return None
 
-    def currentPartialUnit(self):
-        """Return unit with at least a partial match, o/w None.
-        """
-        currentUnit = self.currentUnit()
-        if not currentUnit:
-            return None
-        return self.unitData.findPartialMatch(currentUnit.name)
-
-    def currentSortPos(self):
-        """Return unit near current unit for sorting.
-        """
-        try:
-            return self.unitData.findSortPos(self.currentUnit().name)
-        except AttributeError:
-            return self.unitData[self.unitData.sortedKeys[0]]
-
     def replaceCurrent(self, newUnit):
-        """Replace the current unit with unit.
+        """Replace the current unit with unit datum.
         """
         if self.unitList:
             oldUnit = self.currentUnit()
             group, pos = self.currentGroupPos()
-            group.unitList[pos] = newUnit.copy()
+            group.unitList[pos] = unitatom.UnitAtom('', newUnit)
             group.unitList[pos].exp = oldUnit.exp
-            return
-        self.unitList.append(newUnit.copy())
-
-    def completePartial(self):
-        """Replace a partial unit with a full one.
-        """
-        partUnit = self.currentUnit()
-        if partUnit and not partUnit.equiv:
-            newUnit = self.unitData.findPartialMatch(partUnit.name)
-            if newUnit:
-                self.replaceCurrent(newUnit)
-
-    def moveToNext(self, upward):
-        """Replace unit with adjacent one based on match or sort position.
-        """
-        unit = self.currentSortPos()
-        name = unit.name.lower().replace(' ', '')
-        num = self.unitData.sortedKeys.index(name) + (upward and -1 or 1)
-        if 0 <= num < len(self.unitData.sortedKeys):
-            self.replaceCurrent(self.unitData[self.unitData.sortedKeys[num]])
+        else:
+            self.unitList.append(unitatom.UnitAtom('', newUnit))
 
     def addOper(self, mult):
         """Add new operator & blank unit after current, * if mult is true.
         """
         if self.unitList:
-            self.completePartial()
             group, pos = self.currentGroupPos()
             self.currentNum += 1
-            group.unitList.insert(pos + 1, UnitAtom(''))
+            group.unitList.insert(pos + 1, unitatom.UnitAtom(''))
             if not mult:
                 self.currentUnit().exp = -1
 
     def changeExp(self, newExp):
         """Change the current unit's exponent.
         """
-        self.completePartial()
         currentUnit = self.currentUnit()
         if currentUnit:
             if currentUnit.exp > 0:
@@ -219,25 +183,46 @@ class UnitGroup(object):
         """
         parts = text.split('^', 1)
         exp = 1
+        partialExp = ''
         if len(parts) > 1:   # has exponent
+            expText = parts[1].strip()
             try:
-                exp = int(parts[1])
+                exp = int(expText)
+                if exp == 1:
+                    partialExp = '^1'  # keep for start of '1.5'
+                elif expText == '-0':
+                    partialExp = '^-0' # keep for start of '-0.5'
             except ValueError:
-                if parts[1].lstrip().startswith('-'):
-                    exp = -UnitAtom.partialExp  # tmp invalid exp
-                else:
-                    exp = UnitAtom.partialExp
+                try:
+                    exp = float(expText)
+                    if expText.endswith('.'):
+                        partialExp = '^' + expText
+                except ValueError:
+                    if expText == '.':
+                        partialExp = '^0.'
+                    elif expText == '-.':
+                        partialExp = '^-0.'
+                    elif expText.startswith('-'):
+                        partialExp = '^-'
+                    else:
+                        partialExp = '^'
+                    exp = unitatom.UnitAtom.invalidExp
         unitText = parts[0].strip().lower().replace(' ', '')
-        unit = self.unitData.get(unitText, None)
-        if not unit and unitText and unitText[-1] == 's' and not \
-           self.unitData.findPartialMatch(unitText):   # check for plural
-            unit = self.unitData.get(unitText[:-1], None)
-        if not unit:
-            unit = UnitAtom('')   # tmp invalid unit
-            unit.name = parts[0].strip()
-        unit = unit.copy()
-        unit.exp = exp
-        return unit
+        unit = self.unitData.get(unitText)
+        if not unit and unitText:
+            if unitText[-1] in ('2', '3') and self.unitData.get(unitText[:-1]):
+                unit = self.unitData.get(unitText[:-1])
+                exp = int(unitText[-1])
+            elif (unitText[-1] == 's' and not
+                  self.unitData.findPartialMatch(unitText)): # check for plural
+                unit = self.unitData.get(unitText[:-1])
+        if unit:
+            unitAtom = unitatom.UnitAtom('', unit)
+        else:
+            unitAtom = unitatom.UnitAtom(parts[0].strip())  # tmp invalid unit
+        unitAtom.exp = exp
+        unitAtom.partialExp = partialExp
+        return unitAtom
 
     def unitString(self, unitList=None, swapExpSign=False):
         """Return the full string for this group or a given group.
@@ -250,7 +235,7 @@ class UnitGroup(object):
             for unit in unitList:
                 if not firstUnit:
                     if hasattr(unit, 'exp'):
-                        expSign = unit.exp > 0
+                        expSign = unit.exp >= 0
                     else:
                         expSign = unit.unitGroupExpSign()
                     if swapExpSign:
@@ -301,21 +286,23 @@ class UnitGroup(object):
             if count > 5000:
                 raise unitdata.UnitDataError(_('Circular unit definition'))
             unit = tmpList.pop(0)
-            if unit.equiv.startswith('!'):
-                self.reducedList.append(unit.copy())
-            elif not unit.equiv:
+            if unit.datum.equiv.startswith('!'):
+                newUnit = unitatom.UnitAtom('', unit.datum)
+                newUnit.exp = unit.exp
+                self.reducedList.append(newUnit)
+            elif not unit.datum.equiv:
                 raise unitdata.UnitDataError(_('Invalid conversion for "{0}"').
-                                             format(unit.name))
+                                             format(unit.unitName))
             else:
-                if unit.fromEqn:
+                if unit.datum.fromEqn:
                     self.linear = False
                 equivUnit = UnitGroup(self.unitData, self.option)
-                equivUnit.update(unit.equiv)
+                equivUnit.update(unit.datum.equiv)
                 newList = equivUnit.flatUnitList()
                 for newUnit in newList:
                     newUnit.exp *= unit.exp
                 tmpList.extend(newList)
-                self.factor *= unit.factor**unit.exp
+                self.factor *= unit.datum.factor**unit.exp
         self.reducedList.sort()
         tmpList = self.reducedList[:]
         self.reducedList = []
@@ -325,17 +312,17 @@ class UnitGroup(object):
             else:
                 self.reducedList.append(unit)
         self.reducedList = [unit for unit in self.reducedList if
-                            unit.equiv != '!!' and unit.name != 'unit' and
-                            unit.exp != 0]
+                            unit.datum.equiv != '!!' and
+                            unit.datum.name != 'unit' and unit.exp != 0]
 
     def categoryMatch(self, otherGroup):
         """Return True if unit types are equivalent.
         """
         if not self.checkLinear() or not otherGroup.checkLinear():
             return False
-        return self.reducedList == otherGroup.reducedList and \
-               [unit.exp for unit in self.reducedList] == \
-               [unit.exp for unit in otherGroup.reducedList]
+        return (self.reducedList == otherGroup.reducedList and
+                [unit.exp for unit in self.reducedList] ==
+                [unit.exp for unit in otherGroup.reducedList])
 
     def checkLinear(self):
         """Return True if linear or acceptable non-linear.
@@ -370,11 +357,11 @@ class UnitGroup(object):
         x = num
         try:
             unit = self.flatUnitList()[0]
-            if unit.toEqn:      # regular equations
+            if unit.datum.toEqn:      # regular equations
                 if isFrom:
-                    return float(eval(unit.fromEqn))
-                return float(eval(unit.toEqn))
-            data = list(eval(unit.fromEqn))  # extrapolation list
+                    return float(eval(unit.datum.fromEqn))
+                return float(eval(unit.datum.toEqn))
+            data = list(eval(unit.datum.fromEqn))  # extrapolation list
             if isFrom:
                 data = [(float(group[0]), float(group[1])) for group in data]
             else:
@@ -393,7 +380,7 @@ class UnitGroup(object):
             return 1e9999
         except:
             raise unitdata.UnitDataError(_('Bad equation for {0}').
-                                         format(unit.name))
+                                         format(unit.datum.name))
 
     def convertStr(self, num, toGroup):
         """Return formatted string of converted number.
@@ -410,7 +397,10 @@ class UnitGroup(object):
         if notation == 'scientific':
             return '{0:0.{prec}E}'.format(num, prec = decPlcs)
         if notation == 'engineering':
-            exp = 3 * (floor(log10(abs(num))) // 3)
+            try:
+                exp = 3 * (floor(log10(abs(num))) // 3)
+            except ValueError:  # log10 of zero is undefined
+                exp = 0
             num = round(num / 10**exp, decPlcs)
             # check if rounding bumps exponent
             if abs(num) >= 1000.0:
