@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de_DE">
+<!DOCTYPE TS>
+<TS version="2.0" language="de_DE">
 <context>
     <name>cmdline</name>
     <message>
@@ -126,72 +127,72 @@
         <translation type="obsolete">Fehler in Einheitendaten - %s</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="85"/>
+        <location filename="convertdlg.py" line="93"/>
         <source>From Unit</source>
         <translation>Ausgangseinheit</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="100"/>
+        <location filename="convertdlg.py" line="99"/>
         <source>To Unit</source>
         <translation>Zieleinheit</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="117"/>
+        <location filename="convertdlg.py" line="160"/>
         <source>Set units</source>
         <translation>Einheit angeben</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="134"/>
+        <location filename="convertdlg.py" line="179"/>
         <source>No Unit Set</source>
         <translation>Keine Einheit angegeben</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="152"/>
+        <location filename="convertdlg.py" line="197"/>
         <source>&amp;Close</source>
         <translation>S&amp;chließen</translation>
     </message>
     <message>
         <location filename="convertdlg.py" line="156"/>
         <source>&amp;Unit Finder...</source>
-        <translation>Einheit s&amp;uchen...</translation>
+        <translation type="obsolete">Einheit s&amp;uchen...</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="160"/>
+        <location filename="convertdlg.py" line="201"/>
         <source>&amp;Options...</source>
         <translation>&amp;Optionen...</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="164"/>
+        <location filename="convertdlg.py" line="205"/>
         <source>&amp;Help...</source>
         <translation>&amp;Hilfe...</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="168"/>
+        <location filename="convertdlg.py" line="209"/>
         <source>&amp;About...</source>
         <translation>&amp;Über...</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="207"/>
+        <location filename="convertdlg.py" line="142"/>
         <source>Clear Unit</source>
         <translation>Einheit löschen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="283"/>
+        <location filename="convertdlg.py" line="320"/>
         <source>Result Display</source>
         <translation>Ergebnis-Ausgabe</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="280"/>
+        <location filename="convertdlg.py" line="317"/>
         <source>Decimal places</source>
         <translation>Dezimalstellen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="286"/>
+        <location filename="convertdlg.py" line="323"/>
         <source>Use scientific notation</source>
         <translation>Wissenschaftliche Darstellung nutzen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="285"/>
+        <location filename="convertdlg.py" line="322"/>
         <source>Use fixed decimal places</source>
         <translation>Festkommadarstellung nutzen</translation>
     </message>
@@ -203,35 +204,35 @@
     <message>
         <location filename="convertdlg.py" line="294"/>
         <source>Show operator buttons</source>
-        <translation>Schaltflächen für Rechenoperationen anzeigen</translation>
+        <translation type="obsolete">Schaltflächen für Rechenoperationen anzeigen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="297"/>
+        <location filename="convertdlg.py" line="336"/>
         <source>Colors</source>
         <translation>Farben</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="299"/>
+        <location filename="convertdlg.py" line="338"/>
         <source>Use default system colors</source>
         <translation>Systemfarben nutzen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="300"/>
+        <location filename="convertdlg.py" line="339"/>
         <source>Set background color</source>
         <translation>Hintergrundfarbe setzen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="301"/>
+        <location filename="convertdlg.py" line="340"/>
         <source>Set text color</source>
         <translation>Textfarbe setzen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="379"/>
+        <location filename="convertdlg.py" line="408"/>
         <source>Read Me file not found</source>
         <translation>README-Datei nicht gefunden</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="382"/>
+        <location filename="convertdlg.py" line="411"/>
         <source>ConvertAll README File</source>
         <translation>ConvertAll-README-Datei</translation>
     </message>
@@ -243,66 +244,66 @@ by %s</source>
 von %s</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="216"/>
+        <location filename="convertdlg.py" line="144"/>
         <source>Recent Unit</source>
         <translation>Zuletzt benutzte Einheit</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="288"/>
+        <location filename="convertdlg.py" line="325"/>
         <source>Recent Units</source>
         <translation>Zuletzt benutzte Einheiten</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="289"/>
+        <location filename="convertdlg.py" line="326"/>
         <source>Number saved</source>
         <translation>Gespeicherte Anzahl</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="68"/>
+        <location filename="convertdlg.py" line="71"/>
         <source>Error in unit data - {0}</source>
         <translation>Fehler in Einheitendaten - {0}</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="71"/>
+        <location filename="convertdlg.py" line="74"/>
         <source>{0} units loaded</source>
         <translation>{0} Einheiten geladen</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="291"/>
+        <location filename="convertdlg.py" line="328"/>
         <source>Load last units at startup</source>
-        <translation type="unfinished">Laden der letzten Einheiten beim Start</translation>
+        <translation>Laden der letzten Einheiten beim Start</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="292"/>
+        <location filename="convertdlg.py" line="329"/>
         <source>User Interface</source>
         <translation>User Interface</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="296"/>
+        <location filename="convertdlg.py" line="335"/>
         <source>Show tip at startup</source>
-        <translation type="unfinished">Zeige Hinweise beim Start</translation>
+        <translation>Zeige Hinweise beim Start</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="390"/>
+        <location filename="convertdlg.py" line="419"/>
         <source>ConvertAll Version {0}
 by {1}</source>
         <translation>ConvertAll Version {0}
 von {1}</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="418"/>
+        <location filename="convertdlg.py" line="447"/>
         <source>Convertall - Tip</source>
         <translation>Convertall - Hinweis</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="444"/>
+        <location filename="convertdlg.py" line="473"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="422"/>
+        <location filename="convertdlg.py" line="451"/>
         <source>Combining Units</source>
-        <translation type="unfinished">Die Kombination von Einheiten</translation>
+        <translation>Die Kombination von Einheiten</translation>
     </message>
     <message>
         <location filename="convertdlg.py" line="431"/>
@@ -310,143 +311,183 @@ von {1}</translation>
         <translation type="obsolete">&lt;p&gt;ConvertAll Stärke ist die Fähigkeit, Geräte zu kombinieren:&lt;/p&gt;&lt;ul&gt;&lt;li&gt;Geben Sie &quot;m / s&quot; in Meter pro Sekunde zu bekommen&lt;/li&gt;&lt;li&gt;geben Sie &quot;ft · lbf&quot;, um Fuß-Pfund (Drehmoment) zu erhalten&lt;li&gt;&lt;li&gt;Enter &quot;in ^ 2&quot; auf Platz Zoll zu bekommen&lt;/li&gt;&lt;li&gt;geben Sie &quot;m ^ 3 &quot;, um Kubikmeter&lt;/li&lt;li&gt;oder andere Kombinationen, die Sie sich vorstellen können zu&lt;/li&gt;&lt;/ul&gt;</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="439"/>
+        <location filename="convertdlg.py" line="468"/>
         <source>Show this tip at startup</source>
-        <translation type="unfinished">Zeige diesen Hinweis beim Start</translation>
+        <translation>Zeige diesen Hinweis beim Start</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="434"/>
+        <location filename="convertdlg.py" line="463"/>
         <source>&lt;p&gt;ConvertAll&apos;s strength is the ability to combine units:&lt;/p&gt;&lt;ul&gt;&lt;li&gt;Enter &quot;m/s&quot; to get meters per second&lt;/li&gt;&lt;li&gt;Enter &quot;ft*lbf&quot; to get foot-pounds (torque)&lt;/li&gt;&lt;li&gt;Enter &quot;in^2&quot; to get square inches&lt;/li&gt;&lt;li&gt;Enter &quot;m^3&quot; to get cubic meters&lt;/li&gt;&lt;li&gt;or any other combinations you can imagine&lt;/li&gt;&lt;/ul&gt;</source>
-        <translation type="unfinished">&lt;p&gt;Die Stärke von ConvertAll ist die Fähigkeit, Einheiten zu kombinieren:&lt;/p&gt;&lt;ul&gt;&lt;li&gt;Geben Sie &quot;m / s&quot; ein, um Meter pro Sekunde zu bekommen&lt;/li&gt;&lt;li&gt;Geben Sie &quot;ft · lbf&quot; ein, um Fuß-Pfund (Drehmoment) zu bekommen&lt;li&gt;&lt;li&gt;Geben Sie &quot;in ^ 2&quot; ein, um Quadratzoll zu bekommen&lt;/li&gt;&lt;li&gt;Geben Sie &quot;m ^ 3 &quot; ein, um Kubikmeter zu bekommen&lt;/li&gt;&lt;li&gt;oder jede andere Kombinationen, die Sie sich vorstellen können&lt;/li&gt;&lt;/ul&gt;</translation>
+        <translation>&lt;p&gt;Die Stärke von ConvertAll ist die Fähigkeit, Einheiten zu kombinieren:&lt;/p&gt;&lt;ul&gt;&lt;li&gt;Geben Sie &quot;m / s&quot; ein, um Meter pro Sekunde zu bekommen&lt;/li&gt;&lt;li&gt;Geben Sie &quot;ft · lbf&quot; ein, um Fuß-Pfund (Drehmoment) zu bekommen&lt;li&gt;&lt;li&gt;Geben Sie &quot;in ^ 2&quot; ein, um Quadratzoll zu bekommen&lt;/li&gt;&lt;li&gt;Geben Sie &quot;m ^ 3 &quot; ein, um Kubikmeter zu bekommen&lt;/li&gt;&lt;li&gt;oder jede andere Kombinationen, die Sie sich vorstellen können&lt;/li&gt;&lt;/ul&gt;</translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="279"/>
+        <location filename="convertdlg.py" line="316"/>
         <source>Result Precision</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="284"/>
+        <location filename="convertdlg.py" line="321"/>
         <source>Use short representation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="convertdlg.py" line="287"/>
+        <location filename="convertdlg.py" line="324"/>
         <source>Use engineering notation</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="convertdlg.py" line="127"/>
+        <source>Square</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="convertdlg.py" line="128"/>
+        <source>Cube</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="convertdlg.py" line="129"/>
+        <source>Multiply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="convertdlg.py" line="130"/>
+        <source>Divide</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="convertdlg.py" line="259"/>
+        <source>Filter List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="convertdlg.py" line="273"/>
+        <source>Clear Filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="convertdlg.py" line="331"/>
+        <source>Show operator buttons (1st row)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="convertdlg.py" line="333"/>
+        <source>Show unit buttons (2nd row)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>finddlg</name>
     <message>
         <location filename="finddlg.py" line="28"/>
         <source>Unit Finder</source>
-        <translation>Einheitensuche</translation>
+        <translation type="obsolete">Einheitensuche</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="35"/>
         <source>&amp;Filter Unit Types</source>
-        <translation>Einheitentypen &amp;filtern</translation>
+        <translation type="obsolete">Einheitentypen &amp;filtern</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="41"/>
         <source>&amp;Search String</source>
-        <translation>&amp;Suchtext</translation>
+        <translation type="obsolete">&amp;Suchtext</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="46"/>
         <source>C&amp;lear</source>
-        <translation>&amp;Löschen</translation>
+        <translation type="obsolete">&amp;Löschen</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="55"/>
         <source>From Unit</source>
-        <translation>Ausgangseinheit</translation>
+        <translation type="obsolete">Ausgangseinheit</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="58"/>
         <source>&amp;Replace</source>
-        <translation>&amp;Ersetzen</translation>
+        <translation type="obsolete">&amp;Ersetzen</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="61"/>
         <source>&amp;Insert</source>
-        <translation>E&amp;infügen</translation>
+        <translation type="obsolete">E&amp;infügen</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="64"/>
         <source>To Unit</source>
-        <translation>Zieleinheit</translation>
+        <translation type="obsolete">Zieleinheit</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="67"/>
         <source>Replac&amp;e</source>
-        <translation>E&amp;rsetzen</translation>
+        <translation type="obsolete">E&amp;rsetzen</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="70"/>
         <source>Inser&amp;t</source>
-        <translation>Ein&amp;fügen</translation>
+        <translation type="obsolete">Ein&amp;fügen</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="76"/>
         <source>&amp;Close</source>
-        <translation>S&amp;chließen</translation>
+        <translation type="obsolete">S&amp;chließen</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="194"/>
         <source>Unit Name</source>
-        <translation>Einheitenname</translation>
+        <translation type="obsolete">Einheitenname</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="194"/>
         <source>Unit Type</source>
-        <translation>Einheitentyp</translation>
+        <translation type="obsolete">Einheitentyp</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="194"/>
         <source>Comments</source>
-        <translation>Kommentare</translation>
+        <translation type="obsolete">Kommentare</translation>
     </message>
     <message>
         <location filename="finddlg.py" line="135"/>
         <source>[All]</source>
-        <translation>[Alle]</translation>
+        <translation type="obsolete">[Alle]</translation>
     </message>
 </context>
 <context>
     <name>helpview</name>
     <message>
-        <location filename="helpview.py" line="43"/>
+        <location filename="helpview.py" line="46"/>
         <source>&amp;Back</source>
         <translation>&amp;Zurück</translation>
     </message>
     <message>
-        <location filename="helpview.py" line="51"/>
+        <location filename="helpview.py" line="54"/>
         <source>&amp;Forward</source>
         <translation>&amp;Weiter</translation>
     </message>
     <message>
-        <location filename="helpview.py" line="59"/>
+        <location filename="helpview.py" line="62"/>
         <source>&amp;Home</source>
         <translation>Zum &amp;Anfang</translation>
     </message>
     <message>
-        <location filename="helpview.py" line="67"/>
+        <location filename="helpview.py" line="70"/>
         <source>Find</source>
         <translation> Suchen</translation>
     </message>
     <message>
-        <location filename="helpview.py" line="74"/>
+        <location filename="helpview.py" line="77"/>
         <source>Find &amp;Previous</source>
         <translation>&amp;Rückwärts Suchen</translation>
     </message>
     <message>
-        <location filename="helpview.py" line="81"/>
+        <location filename="helpview.py" line="84"/>
         <source>Find &amp;Next</source>
         <translation>&amp;Vorwärts Suchen</translation>
     </message>
     <message>
-        <location filename="helpview.py" line="114"/>
+        <location filename="helpview.py" line="117"/>
         <source>Text string not found</source>
         <translation>String nicht gefunden</translation>
     </message>
@@ -459,7 +500,7 @@ von {1}</translation>
         <translation type="obsolete">Fehler in Einheitendaten - %s</translation>
     </message>
     <message>
-        <location filename="numedit.py" line="57"/>
+        <location filename="numedit.py" line="58"/>
         <source>Converting...</source>
         <translation>Konvertiere...</translation>
     </message>
@@ -469,22 +510,22 @@ von {1}</translation>
         <translation type="obsolete">Einheiten sind nicht kompatibel (%s bzw. %s)</translation>
     </message>
     <message>
-        <location filename="numedit.py" line="76"/>
+        <location filename="numedit.py" line="77"/>
         <source>Set units</source>
         <translation>Einheiten angeben</translation>
     </message>
     <message>
-        <location filename="numedit.py" line="77"/>
+        <location filename="numedit.py" line="78"/>
         <source>No Unit Set</source>
         <translation>Keine Einheit angegeben</translation>
     </message>
     <message>
-        <location filename="numedit.py" line="102"/>
+        <location filename="numedit.py" line="103"/>
         <source>Error in unit data - {0}</source>
         <translation>Fehler in Einheitendaten - {0}</translation>
     </message>
     <message>
-        <location filename="numedit.py" line="70"/>
+        <location filename="numedit.py" line="71"/>
         <source>Units are not compatible ({0}  vs.  {1})</source>
         <translation>Einheiten sind nicht kompatibel ({0} bzw. {1})</translation>
     </message>
@@ -492,17 +533,17 @@ von {1}</translation>
 <context>
     <name>optiondlg</name>
     <message>
-        <location filename="optiondlg.py" line="38"/>
+        <location filename="optiondlg.py" line="42"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="optiondlg.py" line="41"/>
+        <location filename="optiondlg.py" line="45"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Abbrechen</translation>
     </message>
     <message>
-        <location filename="optiondlg.py" line="44"/>
+        <location filename="optiondlg.py" line="48"/>
         <source>Preferences</source>
         <translation>Voreinstellungen</translation>
     </message>
@@ -515,7 +556,7 @@ von {1}</translation>
         <translation type="obsolete">Ungültige Gleichung für &quot;%s&quot;</translation>
     </message>
     <message>
-        <location filename="unitatom.py" line="45"/>
+        <location filename="unitatom.py" line="46"/>
         <source>Bad equation for &quot;{0}&quot;</source>
         <translation>Ungültige Gleichung für &quot;{0}&quot;</translation>
     </message>
@@ -528,7 +569,7 @@ von {1}</translation>
         <translation>Kann Datei &quot;units.dat&quot; nicht lesen</translation>
     </message>
     <message>
-        <location filename="unitdata.py" line="86"/>
+        <location filename="unitdata.py" line="82"/>
         <source>Duplicate unit names found</source>
         <translation>Einheitennamen mehrfach vorhanden</translation>
     </message>
@@ -536,7 +577,7 @@ von {1}</translation>
 <context>
     <name>unitgroup</name>
     <message>
-        <location filename="unitgroup.py" line="302"/>
+        <location filename="unitgroup.py" line="287"/>
         <source>Circular unit definition</source>
         <translation>Einheitendefinition enthält Selbstbezug</translation>
     </message>
@@ -546,7 +587,7 @@ von {1}</translation>
         <translation type="obsolete">Ungültige Umwandlung für &quot;%s&quot;</translation>
     </message>
     <message>
-        <location filename="unitgroup.py" line="356"/>
+        <location filename="unitgroup.py" line="343"/>
         <source>Cannot combine non-linear units</source>
         <translation>Kann keine nichtlinearen Einheiten kombinieren</translation>
     </message>
@@ -556,12 +597,12 @@ von {1}</translation>
         <translation type="obsolete">Ungültige Gleichung für %s</translation>
     </message>
     <message>
-        <location filename="unitgroup.py" line="307"/>
+        <location filename="unitgroup.py" line="294"/>
         <source>Invalid conversion for &quot;{0}&quot;</source>
         <translation>Ungültige Umwandlung für &quot;{0}&quot;</translation>
     </message>
     <message>
-        <location filename="unitgroup.py" line="395"/>
+        <location filename="unitgroup.py" line="382"/>
         <source>Bad equation for {0}</source>
         <translation>Ungültige Gleichung für {0}</translation>
     </message>
@@ -569,17 +610,17 @@ von {1}</translation>
 <context>
     <name>unitlistview</name>
     <message>
-        <location filename="unitlistview.py" line="30"/>
+        <location filename="unitlistview.py" line="35"/>
         <source>Unit Name</source>
         <translation>Einheitenname</translation>
     </message>
     <message>
-        <location filename="unitlistview.py" line="30"/>
+        <location filename="unitlistview.py" line="35"/>
         <source>Unit Type</source>
         <translation>Einheitentyp</translation>
     </message>
     <message>
-        <location filename="unitlistview.py" line="30"/>
+        <location filename="unitlistview.py" line="35"/>
         <source>Comments</source>
         <translation>Kommentare</translation>
     </message>
